@@ -4,6 +4,7 @@ from .func_b64 import b64decode, b64encode
 from .func_converters import convert_bquery_result_to_json
 from .func_settings import get_config
 from .func_get_secret import get_secret
+from .func_rdp import obter_ip_conexao_rdp, conectar_rdp
 
 __all__ = [
     "titulo", 
@@ -12,5 +13,7 @@ __all__ = [
     "b64decode", 
     "convert_bquery_result_to_json",
     "get_config",
-    "get_secret"
+    "get_secret",
+    "obter_ip_conexao_rdp",
+    "conectar_rdp"
     ]
\ No newline at end of file
